@@ -824,7 +824,7 @@ class AQuantification(Expression):
         for q in self.quantees: #get all variable in quantification
             for q2 in q.vars:
                 vars.add(q2[0].str)
-        if self.f.variables != vars: # unused variables, te veel variable in quantee, als te weining var wordt parse error gegeven
+        if self.f.variables != vars: # unused variables, te veel variable in quantee, als te weining var wordt parse error ergens anders opgevangen
             set3 = vars - self.f.variables
             while len(set3) > 0:      #alle variable in quantification die niet gebruikt worden zoeken
                 a = set3.pop()
